==> apigeelint-0.4.1.tgz: package/test/legacy/testManagementServer.js <==
/*
  Copyright 2019 Google LLC

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      https://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
*/

var ManagementServer = require("../../lib/package/ManagementServer.js"),
  debug = require("debug")("bundlelinter:ManagementServer"),
  assert = require("assert"),
  mgmtConfig = {};

function test(desc, call, org, args, testFunction, testResult) {
  describe("test: " + desc, function() {
    var ms = new ManagementServer(org);
    it("should return " + testResult, function(done) {
      ms.get(call, { org }, args, function(body, res) {
        var actualResult;
        if (typeof testFunction == "function") {
          actualResult = testFunction(body, res);
        } else {
          actualResult = testFunction;
        }
        try {
          assert.equal(testResult, actualResult);
          done();
        } catch (e) {
          done(e);
        }
      });
    });
  });
}

test(
  "Test Authorization via status code.",
  "Enviros",
  "davidwallen2014",
  {},
  function(body, res) {
    return res.statusCode;
  },
  200
);

test(
  "Number of Enviros in org.",
  "Enviros",
  "davidwallen2014",  {},
  function(body, res) {
    return JSON.parse(body).length || 0;
  },
  2
);
test(
  "Enviros contains test.",
  "Enviros",
  "davidwallen2014",  {},
  function(body, res) {
    return body.indexOf("test") > -1;
  },
  true
);

test(
  "APIs include 24Solver.",
  "OrgAPIs",
  "davidwallen2014",  {},
  function(body, res) {
    return body.indexOf("24Solver") > -1;
  },
  true
);

test(
  "APIs include 24Solver.",
  "Bundle",
  "davidwallen2014",
  { api: "24Solver", revision: 19 },
  function(body, res) {
    return body.length>4000;
  },
  true
);

==> apigeelint-2.46.3.tgz: package/test/legacy/testManagementServer.js <==
/*
  Copyright 2019 Google LLC

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      https://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
*/

var ManagementServer = require("../../lib/package/ManagementServer.js"),
  debug = require("debug")("apigeelint:ManagementServer"),
  assert = require("assert"),
  mgmtConfig = {};

function test(desc, call, org, args, testFunction, testResult) {
  describe("test: " + desc, function() {
    var ms = new ManagementServer(org);
    it("should return " + testResult, function(done) {
      ms.get(call, { org }, args, function(body, res) {
        var actualResult;
        if (typeof testFunction == "function") {
          actualResult = testFunction(body, res);
        } else {
          actualResult = testFunction;
        }
        try {
          assert.equal(testResult, actualResult);
          done();
        } catch (e) {
          done(e);
        }
      });
    });
  });
}

test(
  "Test Authorization via status code.",
  "Enviros",
  "davidwallen2014",
  {},
  function(body, res) {
    return res.statusCode;
  },
  200
);

test(
  "Number of Enviros in org.",
  "Enviros",
  "davidwallen2014",  {},
  function(body, res) {
    return JSON.parse(body).length || 0;
  },
  2
);
test(
  "Enviros contains test.",
  "Enviros",
  "davidwallen2014",  {},
  function(body, res) {
    return body.indexOf("test") > -1;
  },
  true
);

test(
  "APIs include 24Solver.",
  "OrgAPIs",
  "davidwallen2014",  {},
  function(body, res) {
    return body.indexOf("24Solver") > -1;
  },
  true
);

test(
  "APIs include 24Solver.",
  "Bundle",
  "davidwallen2014",
  { api: "24Solver", revision: 19 },
  function(body, res) {
    return body.length>4000;
  },
  true
);
